==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/en-ID/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Konfirmasi hapus semua aset',
    'bulk_restore'      => 'Confirm Bulk Restore Assets', 
  'bulk_delete_help'	=> 'Tinjau aset untuk penghapusan massal di bawah ini. Setelah dihapus, aset ini dapat dipulihkan, namun tidak akan dikaitkan lagi dengan pengguna yang saat ini mereka tentukan.',
  'bulk_restore_help'	=> 'Review the assets for bulk restoration below. Once restored, these assets will not be associated with any users they were previously assigned to.',
  'bulk_delete_warn'	=> 'Anda akan menghapus :asset_count assets.',
  'bulk_restore_warn'	=> 'You are about to restore :asset_count assets.',
    'bulk_update'		=> 'Perbarui Aset secara massal',
    'bulk_update_help'	=> 'Formulir ini memungkinkan Anda untuk memperbarui beberapa aset sekaligus. Hanya mengisi kolom yang Anda butuhkan untuk mengubah. Setiap bidang dibiarkan kosong tidak berubah. ',
    'bulk_update_warn'	=> 'You are about to edit the properties of a single asset.|You are about to edit the properties of :asset_count assets.',
    'bulk_update_with_custom_field' => 'Note the assets are :asset_model_count different types of models.',
    'bulk_update_model_prefix' => 'On Models', 
    'bulk_update_custom_field_unique' => 'This is a unique field and can not be bulk edited.',
    'checkedout_to'		=> 'Checkout ke',
    'checkout_date'		=> 'Tanggal Check out',
    'checkin_date'		=> 'Tanggal Check in',
    'checkout_to'		=> 'Checkout ke',
    'cost'				=> 'Biaya pembelian',
    'create'			=> 'Buat Aset',
    'date'				=> 'Tanggal Pemebelian',
    'depreciation'	    => 'Penyusutan',
    'depreciates_on'	=> 'Penyusutan pada',
    'default_location'	=> 'Lokasi Standar',
    'default_location_phone' => 'Default Location Phone',
    'eol_date'			=> 'Tanggal EOL',
    'eol_rate'			=> 'Nilai EOL',
    'expected_checkin'  => 'Tanggal Checkin yang Diharapkan',
    'expires'			=> 'Kadaluarsa',
    'fully_depreciated'	=> 'Sepenuhnya disusutkan',
    'help_checkout'		=> 'Jika Anda ingin segera menetapkan aset ini, pilih "Ready to Deploy" dari daftar status di atas. ',
    'mac_address'		=> 'Alamat MAC',
    'manufacturer'		=> 'Pabrikan',
    'model'				=> 'Model',
    'months'			=> 'bulan',
    'name'				=> 'Nama Aset',
    'notes'				=> 'Catatan',
    'order'				=> 'Nomor Permintaan',
    'qr'				=> 'Kode QR',
    'requestable'		=> 'Pengguna dapat meminta aset ini',
    'select_statustype'	=> 'Pilih Jenis Status',
    'serial'			=> 'Serial',
    'status'			=> 'Status',
    'tag'				=> 'Tag Aset',
    'update'			=> 'Perbarui aset',
    'warranty'			=> 'Garansi',
        'warranty_expires'		=> 'Garansi kadaluarsa',
    'years'				=> 'tahun',
    'asset_location' => 'Update Asset Location',
    'asset_location_update_default_current' => 'Update default location AND actual location',
    'asset_location_update_default' => 'Update only default location',
    'asset_location_update_actual' => 'Update only actual location',
    'asset_not_deployable' => 'That asset status is not deployable. This asset cannot be checked out.',
    'asset_deployable' => 'That status is deployable. This asset can be checked out.',
    'processing_spinner' => 'Processing... (This might take a bit of time on large files)',
    'optional_infos'  => 'Optional Information',
    'order_details'   => 'Order Related Information'
];

==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/en-ID/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Konfirmasi hapus semua aset',
    'bulk_restore'      => 'Confirm Bulk Restore Assets', 
  'bulk_delete_help'	=> 'Tinjau aset untuk penghapusan massal di bawah ini. Setelah dihapus, aset ini dapat dipulihkan, namun tidak akan dikaitkan lagi dengan pengguna yang saat ini mereka tentukan.',
  'bulk_restore_help'	=> 'Review the assets for bulk restoration below. Once restored, these assets will not be associated with any users they were previously assigned to.',
  'bulk_delete_warn'	=> 'Anda akan menghapus :asset_count assets.',
  'bulk_restore_warn'	=> 'You are about to restore :asset_count assets.',
    'bulk_update'		=> 'Perbarui Aset secara massal',
    'bulk_update_help'	=> 'Formulir ini memungkinkan Anda untuk memperbarui beberapa aset sekaligus. Hanya mengisi kolom yang Anda butuhkan untuk mengubah. Setiap bidang dibiarkan kosong tidak berubah. ',
    'bulk_update_warn'	=> 'You are about to edit the properties of a single asset.|You are about to edit the properties of :asset_count assets.',
    'bulk_update_with_custom_field' => 'Note the assets are :asset_model_count different types of models.',
    'bulk_update_model_prefix' => 'On Models', 
    'bulk_update_custom_field_unique' => 'This is a unique field and can not be bulk edited.',
    'checkedout_to'		=> 'Checkout ke',
    'checkout_date'		=> 'Tanggal Check out',
    'checkin_date'		=> 'Tanggal Check in',
    'checkout_to'		=> 'Checkout ke',
    'cost'				=> 'Biaya pembelian',
    'create'			=> 'Buat Aset',
    'date'				=> 'Tanggal Pemebelian',
    'depreciation'	    => 'Penyusutan',
    'depreciates_on'	=> 'Penyusutan pada',
    'default_location'	=> 'Lokasi Standar',
    'default_location_phone' => 'Default Location Phone',
    'eol_date'			=> 'Tanggal EOL',
    'eol_rate'			=> 'Nilai EOL',
    'expected_checkin'  => 'Tanggal Checkin yang Diharapkan',
    'expires'			=> 'Kadaluarsa',
    'fully_depreciated'	=> 'Sepenuhnya disusutkan',
    'help_checkout'		=> 'Jika Anda ingin segera menetapkan aset ini, pilih "Ready to Deploy" dari daftar status di atas. ',
    'mac_address'		=> 'Alamat MAC',
    'manufacturer'		=> 'Pabrikan',
    'model'				=> 'Model',
    'months'			=> 'bulan',
    'name'				=> 'Nama Aset',
    'notes'				=> 'Catatan',
    'order'				=> 'Nomor Permintaan',
    'qr'				=> 'Kode QR',
    'requestable'		=> 'Pengguna dapat meminta aset ini',
    'redirect_to_all'   => 'Return to all :type',
    'redirect_to_type'   => 'Go to :type',
    'redirect_to_checked_out_to'   => 'Go to Checked Out to',
    'select_statustype'	=> 'Pilih Jenis Status',
    'serial'			=> 'Serial',
    'status'			=> 'Status',
    'tag'				=> 'Tag Aset',
    'update'			=> 'Perbarui aset',
    'warranty'			=> 'Garansi',
        'warranty_expires'		=> 'Garansi kadaluarsa',
    'years'				=> 'tahun',
    'asset_location' => 'Update Asset Location',
    'asset_location_update_default_current' => 'Update default location AND actual location',
    'asset_location_update_default' => 'Update only default location',
    'asset_location_update_actual' => 'Update only actual location',
    'asset_not_deployable' => 'That asset status is not deployable. This asset cannot be checked out.',
    'asset_deployable' => 'That status is deployable. This asset can be checked out.',
    'processing_spinner' => 'Processing... (This might take a bit of time on large files)',
    'optional_infos'  => 'Optional Information',
    'order_details'   => 'Order Related Information'
];
